summaryrefslogtreecommitdiffstats
path: root/korn/accountmanager.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:21 -0600
commit86d8364ac704bdc8ad2dfcf52307d9626cfac567 (patch)
tree97d3ac2c2f60780d9a1de4f82caac7cb27534501 /korn/accountmanager.h
parenta9bde819f2b421dcc44741156e75eca4bb5fb4f4 (diff)
downloadtdepim-86d8364ac704bdc8ad2dfcf52307d9626cfac567.tar.gz
tdepim-86d8364ac704bdc8ad2dfcf52307d9626cfac567.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'korn/accountmanager.h')
-rw-r--r--korn/accountmanager.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/korn/accountmanager.h b/korn/accountmanager.h
index 5e7a0347..e28a8525 100644
--- a/korn/accountmanager.h
+++ b/korn/accountmanager.h
@@ -26,7 +26,7 @@ class KornSubjectsDlg;
class KKioDrop;
class KMailDrop;
-class KConfig;
+class TDEConfig;
template< class T > class TQPtrList;
template< class T, class W > class TQMap;
@@ -55,22 +55,22 @@ public:
/**
* This function is used to read the config.
*
* @param config The KConfig instance to the configuration
* @param index The index of the box. As there are different boxes,
* every box have it's own index. This number is used to get the
* right config-information out of the config parameter.
*/
- virtual void readConfig( KConfig* config, const int index );
+ virtual void readConfig( TDEConfig* config, const int index );
/**
* This write the configuration into a file. Things that must be right is
* for example the reset number. The configuration isn't saved through this
* method; configurations are saved in the configurations classes.
*
* @param config The KConfig instance to which the configuration is written.
* @param index The index of the box.
*/
- virtual void writeConfig( KConfig* config, const int index );
+ virtual void writeConfig( TDEConfig* config, const int index );
/**
* This method makes a TQString which can be used for a tooltip.
@@ -55,22 +55,22 @@ public:
* This function is used to read the config.
*
- * @param config The KConfig instance to the configuration
+ * @param config The TDEConfig instance to the configuration
* @param index The index of the box. As there are different boxes,
* every box have it's own index. This number is used to get the
@@ -55,22 +55,22 @@ public:
* method; configurations are saved in the configurations classes.
*
- * @param config The KConfig instance to which the configuration is written.
+ * @param config The TDEConfig instance to which the configuration is written.
* @param index The index of the box.
*/